@@ -707,7 +707,7 @@ void syck_emit_scalar( SyckEmitter *e, char *tag, enum scalar_style force_style,
     /* Determine block style */
     if ( (scan & SCAN_NONPRINT) && (e->style != scalar_fold) ) {
         force_style = scalar_2quote;
-    } else if ( force_style != scalar_1quote && ( scan & SCAN_WHITEEDGE ) ) {
+    } else if ( force_style != scalar_1quote && force_style != scalar_literal && ( scan & SCAN_WHITEEDGE ) ) {
         force_style = scalar_2quote;
     } else if ( force_style != scalar_fold && ( scan & SCAN_INDENTED ) ) {
         force_style = scalar_literal;
@@ -742,7 +742,7 @@ void syck_emit_scalar( SyckEmitter *e, char *tag, enum scalar_style force_style,
 
     /* If the parent is an inline, double quote anything complex */
     if ( parent->status == syck_lvl_imap || parent->status == syck_lvl_iseq ) {
-        if ( force_style != scalar_plain && force_style != scalar_1quote ) {
+        if ( force_style != scalar_plain && force_style != scalar_1quote && force_style != scalar_literal) {
             force_style = scalar_2quote;
         }
     }
@@ -772,7 +772,7 @@ void syck_emit_scalar( SyckEmitter *e, char *tag, enum scalar_style force_style,
 
         case scalar_literal:
             /* syck_emit_literal( e, keep_nl, str, len ); */
-            syck_emit_2quoted( e, force_width, str, len );
+            syck_emit_2quoted_1( e, force_width, str, len );
         break;
 
         case scalar_plain:
@@ -863,6 +863,69 @@ void syck_emit_1quoted( SyckEmitter *e, int width, char *str, long len )
     syck_emitter_write( e, "'", 1 );
 }
 
+/*
+ * Outputs a double-quoted block.
+ */
+void syck_emit_2quoted_1( SyckEmitter *e, int width, char *str, long len )
+{
+    char do_indent = 0;
+    char *mark = str;
+    char *start = str;
+    char *end = str;
+    syck_emitter_write( e, "\'", 1 );
+    while ( mark < str + len ) {
+        if ( do_indent > 0 ) {
+            if ( do_indent == 2 ) {
+                syck_emitter_write( e, "\\", 1 );
+            }
+            syck_emit_indent( e );
+            do_indent = 0;
+        }
+        switch ( *mark ) {
+
+            /* Escape sequences allowed within double quotes. */
+            case '\'': syck_emitter_write( e, "\\\'", 2 ); break;
+            case '\\': syck_emitter_write( e, "\\\\", 2 ); break;
+            case '\0': syck_emitter_write( e, "\\0",  2 ); break;
+            case '\a': syck_emitter_write( e, "\\a",  2 ); break;
+            case '\b': syck_emitter_write( e, "\\b",  2 ); break;
+            case '\f': syck_emitter_write( e, "\\f",  2 ); break;
+            case '\r': syck_emitter_write( e, "\\r",  2 ); break;
+            case '\t': syck_emitter_write( e, "\\t",  2 ); break;
+            case '\v': syck_emitter_write( e, "\\v",  2 ); break;
+            case 0x1b: syck_emitter_write( e, "\\e",  2 ); break;
+            case '\n': syck_emitter_write( e, "\\n",  2 ); break;
+
+            /* XXX - Disabled by Audrey Tang for YAML.pm compat
+            case '\n':
+                end = mark + 1;
+                syck_emitter_write( e, "\\n", 2 );
+                do_indent = e->indent;
+                start = mark + 1;
+                if ( start < str + len && ( *start == ' ' || *start == '\n' ) ) {
+                    do_indent = 0;
+                }
+            break;
+            */
+
+            case ' ':
+                if ( width > 0 && *start != ' ' && mark - end > width ) {
+                    do_indent = 1;
+                    end = mark + 1;
+                } else {
+                    syck_emitter_write( e, " ", 1 );
+                }
+            break;
+
+            default:
+                syck_emitter_escape( e, mark, 1 );
+            break;
+        }
+        mark++;
+    }
+    syck_emitter_write( e, "\'", 1 );
+}
+
 /*
  * Outputs a double-quoted block.
  */
